"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/* eslint-disable no-plusplus */
const fs_1 = require("fs");
/**
 * 向指定文件添加内容
 *
 * @param {string} targetFilePath
 * @param {(...(string | ReadStream)[])} contents
 */
async function appendContentToFile(targetFilePath, ...contents) {
    const writer = fs_1.createWriteStream(targetFilePath, {
        flags: 'a',
    });
    const append = (content, end = false) => {
        return new Promise((resolve, reject) => {
            if (typeof content === 'string') {
                const cb = (error) => {
                    if (error) {
                        reject(error);
                    }
                    else {
                        resolve();
                    }
                };
                if (end) {
                    writer.end(content, cb);
                }
                writer.write(content, cb);
            }
            else {
                const stream = content.pipe(writer, {
                    end,
                });
                content.on('end', () => {
                    resolve();
                });
                stream.on('error', (error) => {
                    reject(error);
                });
            }
        });
    };
    for (let i = 0; i < contents.length; i++) {
        // eslint-disable-next-line no-await-in-loop
        await append(contents[i], i === contents.length - 1);
    }
}
exports.default = appendContentToFile;
//# sourceMappingURL=appendContentToFile.js.map