"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const fs_extra_1 = require("fs-extra");
const path_1 = require("path");
const paths_1 = require("../config/paths");
const appendContentToFile_1 = tslib_1.__importDefault(require("./fns/appendContentToFile"));
function getHomepage(options) {
    if (options.packageName.startsWith('@')) {
        const matches = options.packageName.match(/@([^/])\/(.+)/);
        if (matches) {
            const [, scopeName, packageName] = matches;
            return `https://${scopeName}.github.io/${packageName}`;
        }
    }
    return undefined;
}
/**
 * 生成docz文件
 */
async function genDoczFiles(projectPath, options) {
    // 拷贝docz文件
    await fs_extra_1.copy(paths_1.DOCZ_TEMPLATE_PATH, projectPath);
    // 更新docz文档页面的标题
    const content = await fs_extra_1.readFile(path_1.resolve(projectPath, './doczrc.js'), 'utf-8');
    await fs_extra_1.writeFile(path_1.resolve(projectPath, './doczrc.js'), content.replace("title: 'rctt',", `title: '${options.projectName}',`));
    // 添加文档命令
    const packageInfo = await fs_extra_1.readJSON(path_1.resolve(projectPath, './package.json'));
    packageInfo.scripts['doc:dev'] = 'docz dev';
    packageInfo.scripts['doc:build'] = 'docz build';
    if (options.doczGithubPages) {
        packageInfo.scripts['doc:publish'] = 'docz build && gh-pages -d .docz/dist';
        packageInfo.homepage = getHomepage(options);
    }
    await fs_extra_1.outputJSON(path_1.resolve(projectPath, './package.json'), packageInfo, {
        spaces: 2,
    });
    // 添加doc指令说明
    await appendContentToFile_1.default(path_1.resolve(projectPath, 'README.md'), '\n', fs_extra_1.createReadStream(paths_1.DOC_README_PATH));
}
exports.default = genDoczFiles;
//# sourceMappingURL=genDoczFiles.js.map