"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
/* eslint-disable import/prefer-default-export */
/* eslint-disable no-console */
const chalk_1 = tslib_1.__importDefault(require("chalk"));
const ora_1 = tslib_1.__importDefault(require("ora"));
const enquirer_1 = require("enquirer");
const ts_lib_scripts_utils_1 = require("ts-lib-scripts-utils");
const validatePackageName_1 = require("./validatePackageName");
const getOptions_1 = require("./getOptions");
const genProject_1 = require("./genProject");
const paths_1 = require("../config/paths");
const isCmdInstalled_1 = tslib_1.__importDefault(require("./isCmdInstalled"));
const createGitRepository_1 = tslib_1.__importDefault(require("./createGitRepository"));
const gitCommit_1 = tslib_1.__importDefault(require("./gitCommit"));
const installDeps_1 = tslib_1.__importDefault(require("./installDeps"));
const genMonorepoProject_1 = tslib_1.__importDefault(require("./genMonorepoProject"));
const execa = require("execa");
/**
 * 创建项目
 *
 * @param projectName 项目名称
 * @param program 命令行对象
 */
async function create(projectNameConfig, program) {
    const projectName = projectNameConfig.startsWith('@')
        ? projectNameConfig.substr(projectNameConfig.indexOf('/') + 1)
        : projectNameConfig;
    const packageName = (program.packageName || projectNameConfig);
    if (!validatePackageName_1.validatePackageName(packageName)) {
        process.exit(1);
    }
    const options = await getOptions_1.getOptions(projectName, packageName, program);
    if (packageName.startsWith('@') && !options.npmScope && options.monorepo) {
        console.error(`monorepo模式时，项目，项目名称不能以@开头。现在是：${packageName}`);
        return;
    }
    const spinner = ora_1.default().start();
    spinner.start('正在生成项目...');
    try {
        if (options.monorepo) {
            await genMonorepoProject_1.default(options);
        }
        else {
            await genProject_1.genProject(options);
        }
        spinner.succeed(`已生成项目 ${chalk_1.default.green(packageName)}`);
    }
    catch (error) {
        spinner.fail('生成项目失败');
        ts_lib_scripts_utils_1.logError(error);
        process.exit(1);
    }
    const projectPath = paths_1.resolveRoot(options.projectName);
    const gitCreated = createGitRepository_1.default(projectPath);
    await installDeps_1.default(spinner, options);
    if (gitCreated) {
        try {
            gitCommit_1.default(projectPath);
        }
        catch (error) {
            // 忽略git提交失败
        }
    }
    if (isCmdInstalled_1.default('code')) {
        console.log();
        const { openWithCode } = await enquirer_1.prompt({
            type: 'confirm',
            name: 'openWithCode',
            message: '使用vscode打开项目？',
            initial: 'Y',
        });
        if (openWithCode) {
            await execa('code', [projectName]);
        }
    }
    process.exit(0);
}
exports.default = create;
//# sourceMappingURL=index.js.map